==> kwooty-0.4.0.tar.gz: kwooty-0.4.0/src/preferences/preferencesserver.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Xavier Lefage                                   *
 *   xavier.kwooty@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef PREFERENCESSERVER_H
#define PREFERENCESSERVER_H

#include <QWidget>
#include "ui_preferencesserver.h"


class PreferencesServer : public QWidget, public Ui::PreferencesServer
{

     Q_OBJECT

public:
    PreferencesServer();


private:
    void setupConnections();


private slots:
    void portValueChangedSlot(int);

};

#endif // PREFERENCESSERVER_H

==> kwooty-0.6.3.tar.gz: kwooty-0.6.3/src/preferences/preferencesserver.h <==
/***************************************************************************
 *   Copyright (C) 2010 by Xavier Lefage                                   *
 *   xavier.kwooty@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef PREFERENCESSERVER_H
#define PREFERENCESSERVER_H

#include <QWidget>

#include <KConfigDialog>

#include "ui_serversettings.h"
#include "ui_preferencesserver.h"

class ServerTabWidget;


class PreferencesServer : public QWidget, public Ui::PreferencesServer {

     Q_OBJECT

public:

    static const int MAX_SERVERS = 5;

    PreferencesServer(KConfigDialog*);


private:
    ServerTabWidget* tabWidget;
    KConfigDialog* dialog;

    void loadSettings();
    void saveSettings();
    void restorePreviousSettings();
    void defaultSettings();

private slots:
    void configButtonClickedSlot(KDialog::ButtonCode);


public slots:


signals:
    void saveDataSignal();


};

#endif // PREFERENCESSERVER_H
